!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_cs_HW_SM(x)
!******************************************************
!* fit to HW Production cross section for a 7 TeV pp collider
!* (NNLO QCD + NLO EW corrections included)
!* from: https://twiki.cern.ch/twiki/bin/view/LHCPhysics/CERNYellowReportPageAt7TeV
!* (see also: arXiv:1101.0593 [hep-ph])
!******************************************************
!* lhc7_cs_HW_SM : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: strictly valid in range [90:300], deviations from data table below 2.5%
!* (mostly below 0.8% except for the resonance places MH=2 m_W and 2 M_Z)
!*      slight extrapolation to range [80:310] is allowed.
!* 28/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************

        implicit none
        real*8 x,a,b,c,d,e,f,g,h,i,j,k,log_lhc7_cs_HW
        real*8 a0,b0,c0,d0
        real*8 a1,b1,c1,d1

        a0 = 4.804868607203
        b0 = -0.0659883461748213
        c0 = 0.000243548685489925
        d0 = -4.70889637507065e-07

        a1 = 3.44296755151115
        b1 = -0.0410131109918347
        c1 = 7.64351144832779e-05
        d1 = -7.11676632763971e-08

        i = 65349862.8656784
        j = -6752170.81841667
        k = 265404.903034326
        a = -5592.36660816774
        b = 72.0819583239886
        c = -0.602461928193522
        d = 0.00333365446192354
        e = -1.21357053649366e-05
        f = 2.79469426411617e-08
        g = -3.69028673130539e-11
        h = 2.12850198101684e-14

        if(x. lt. 80d0) then
        write(*,*) 'function lhc7_cs_HW_SM(Mh) called out of range (m_H < 80 GeV). Value set to -1.' 
	lhc7_cs_HW_SM=-1d0
	return
	endif
        if((x .ge. 80d0) .and. (x .le. 140d0)) then
        log_lhc7_cs_HW=a0+b0*x+c0*x**2+d0*x**3
        endif
        if((x .gt. 140d0) .and. (x .le. 200d0)) then  
        log_lhc7_cs_HW=i/x**3+j/x**2+k/x+a+b*x+c*x**2+d*x**3+e*x**4+f*x**5+g*x**6+h*x**7
        endif
        if((x .gt. 200d0) .and. (x .le. 310d0)) then
        log_lhc7_cs_HW=a1+b1*x+c1*x**2+d1*x**3
        endif
        if(x .gt. 310d0) then  
        write(*,*) 'function lhc7_cs_HW_SM(Mh) called out of range (m_H > 310 GeV). Value set to -1.' 
	lhc7_cs_HW_SM=-1d0
	return
        endif

        lhc7_cs_HW_SM=exp(log_lhc7_cs_HW)
                                                                                                                        
                                                                                                                                        
        end
        