!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_cs_HZ_SM(x)
!******************************************************
!* fit to HZ Production cross section for a 7 TeV pp collider
!* (NNLO QCD + NLO EW corrections included)
!* from: https://twiki.cern.ch/twiki/bin/view/LHCPhysics/CERNYellowReportPageAt7TeV
!* (see also: arXiv:1101.0593 [hep-ph])
!******************************************************
!* lhc7_cs_HZ_SM : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: strictly valid in range [90:300], deviations from data table below 2.5%
!* (mostly below 0.8% except for the resonance places MH=2 m_W and 2 M_Z)
!*      slight extrapolation to range [80:310] is allowed.
!* 28/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************

        implicit none
        real*8 x,a,b,c,d,e,f,g,h,i,j,k,log_lhc7_cs_HZ
        real*8 a0,b0,c0,d0
        real*8 a1,b1,c1,d1

        a0 = 3.98694547489616
        b0 = -0.0635684565695328
        c0 = 0.000236406731927866
        d0 = -4.54681073848596e-07

        i = -137977615.955026
        j = 7789460.98381851
        k = -189831.552736184
        a = 2620.37934468754
        b = -22.4884711630335
        c = 0.123723493048428
        d = -0.000433669625628974
        e = 9.11236479333671e-07
        f = -9.46984528981245e-10
        g = 8.79379201943118e-14
        h = 4.71246015643876e-16

        a1 = 1.90607728025905
        b1 = -0.0289991532035169
        c1 = 3.00761598372295e-05
        d1 = -1.34210870738984e-08

        if(x. lt. 80d0) then
        write(*,*) 'function lhc7_cs_HZ_SM(Mh) called out of range (m_H < 80 GeV). Value set to -1.' 
	lhc7_cs_HZ_SM=-1d0
	return
	endif
        if((x .ge. 80d0) .and. (x .le. 130d0)) then
        log_lhc7_cs_HZ=a0+b0*x+c0*x**2+d0*x**3
        endif
        if((x .gt. 130d0) .and. (x .le. 220d0)) then  
        log_lhc7_cs_HZ=i/x**3+j/x**2+k/x+a+b*x+c*x**2+d*x**3+e*x**4+f*x**5+g*x**6+h*x**7
        endif
        if((x .gt. 220d0) .and. (x .le. 310d0)) then
        log_lhc7_cs_HZ=a1+b1*x+c1*x**2+d1*x**3
        endif
        if(x .gt. 310d0) then  
        write(*,*) 'function lhc7_cs_HZ_SM(Mh) called out of range (m_H > 310 GeV). Value set to -1.' 
	lhc7_cs_HZ_SM=-1d0
	return
        endif

        lhc7_cs_HZ_SM=exp(log_lhc7_cs_HZ)
                                                                                                                        
                                                                                                                                        
        end
        