!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_cs_HVBF_SM(x)
!******************************************************
!* fit to VBF Process for a 7 TeV pp collider (NNLO QCD + NLO EW)
!* from: https://twiki.cern.ch/twiki/bin/view/LHCPhysics/CERNYellowReportPageAt7TeV
!* (see also: arXiv:1101.0593 [hep-ph])
!******************************************************
!* lhc7_cs_HVBF_SM : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: strictly valid in range [90:1000], deviations from data table below 0.9%
!*      slight extrapolation to range [70:1020] is allowed.
!* 28/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************
        implicit none
        real*8 x,a,b,c,d,e,f,g,h,i,j,k,log_lhc7_cs_HVBF
        real*8 a0,b0,c0,d0

        a0 = 1.58686863728674
        b0 = -0.0132670523407187
        c0 = 1.94912916817487e-05
        d0 = -2.09773046354123e-08

        i = -2588469.20972849
        j = 82811.6396129695
        k = -923.701797379857
        a = 4.83891949608239
        b = 0.00149274570241123
        c = -0.000150420686900271
        d = 6.06559936350697e-07
        e = -1.20388897843419e-09
        f = 1.30902436093564e-12
        g = -7.44981753849372e-16
        h = 1.73712491523886e-19


        if(x. lt. 70d0) then
        write(*,*) 'function lhc7_cs_HVBF_SM(Mh) called out of range (m_H < 70 GeV). Value set to -1.' 
	lhc7_cs_HVBF_SM=-1d0
	return
	endif
        if((x .ge. 70d0) .and. (x .le. 180d0)) then
        log_lhc7_cs_HVBF=a0+b0*x+c0*x**2+d0*x**3
        endif
        if((x .gt. 180d0) .and. (x .le. 1020d0)) then
        log_lhc7_cs_HVBF=i/x**3+j/x**2+k/x+a+b*x+c*x**2+d*x**3+e*x**4+f*x**5+g*x**6+h*x**7        
        endif
        if(x .gt. 1020d0) then
        write(*,*) 'function lhc7_cs_HVBF_SM(Mh) called out of range (m_H > 1020 GeV). Value set to -1.' 
	lhc7_cs_HVBF_SM=-1d0
	return
        endif
                        
        lhc7_cs_HVBF_SM=exp(log_lhc7_cs_HVBF)
                                                                                                                        
                                                                                                                                        
        end
        