!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************


!>>
!#define VERBOSE
!#define DEBUG
!<<


!maximum number of Higgs bosons
#define NHMAX 10

!maximum number of additional data columns in 'additional.dat'
#define MAX_ADDITIONAL_COLUMNS 20

!maximum character length of prefix string
#define LENPREFIX 300

#define LEP_NSneutCHN 17
#define LEP_NScharCHN 6
#define LEP_NDCHN 9
#define LEP_NSCHN (LEP_NSneutCHN+LEP_NScharCHN)

! suggested values : delta_Mh_LEP < 2d0
#define delta_Mh_LEP 0d0
c#define delta_Mhplus_LEP 2d0

#define TEV_NSneutCHN 103
#define TEV_NScharCHN 10
#define TEV_NDCHN 2
#define TEV_NSCHN (TEV_NSneutCHN+TEV_NScharCHN)

! suggested values : delta_Mh_TEV < 10d0
#define delta_Mh_TEV 0d0
c#define delta_Mh_TEV 10d0
c#define delta_Mhplus_TEV 10d0

!maximum numbers of Analyses
#define MAX_LEP1d_ANALYSES (LEP_NSneutCHN+LEP_NScharCHN)
#define MAX_LEP2d_ANALYSES (LEP_NDCHN)
#define MAX_TEV1d_ANALYSES (TEV_NSneutCHN+TEV_NScharCHN) 
#define MAX_TEV2d_ANALYSES (TEV_NDCHN)

!maximum numbers of lines per analysis
! adjust if tables of new analyses have more lines of data
#define MAX_LEP1d_LINES 1087
#define MAX_LEP2d_LINES 200
#define MAX_TEV1d_LINES 1000
#define MAX_TEV2d_LINES 100

! Value of variable eps in subroutine check_TEV_applicability
! Suggested default value: 0.02
#define EPS_SM_LIKENESS 0.02d0

! LEP table identifiers: 

! single neutral Higgs analyses
#define LEPhZ_bbZ	
#define LEPhZ_tautauZ	
#define LEPhZ_anyZ	
#define LEPhZ_invisZ    
#define LEPhZ_gamgamZ	
#define LEPhZ_jjZ       
#define DELPHIbbh_4b	
#define DELPHIbba_4b	
#define DELPHIbbh_2b2tau	
#define OPALbbh_2b2tau	
! 10
#define DELPHIbba_2b2tau	
#define OPALbba_2b2tau	
#define DELPHItautauh_4tau	
#define DELPHItautaua_4tau 
#define DELPHIhZ_invisZ 
! 15
#define L3hZ_invisZ   	
#define OPALhZ_invisZ   



! single charged Higgs analyses
c temporarily removed #define OPALhphm_2tau2nu 
c temporarily removed #define OPALhphm_2jtaunu 
c temporarily removed #define OPALhphm_4j	
#define LEPhphm_4j	
#define DELPHIhphm_4j	
!  5
#define DELPHIhphm_2tau2nu 


! double neutral Higgs analyses
#define LEPh2Z_h1h1Z_4bZ	
#define LEPh2Z_h1h1Z_4tauZ 	
#define LEPh2h1_4b		
#define LEPh2h1_4tau		
#define LEPh2h1_h1h1h1_6b	
! 5
#define LEPh2h1_h1h1h1_6tau	
c temporarily removed #define LEPh2Z_h1h1Z_2b2tau	
#define LEPh2h1_2b2tau		
#define LEPh2h1_2tau2b



! Tevatron & LHC table identifiers:
! single neutral Higgs analyses
#define CDF1009_3047  	
#define CDF10235 	
#define CDF10583 	
#define D06166		
#define D06223		
#define CDF8961_D05536 	
#define CDF10105	
#define D06220		
#define CDF10239	
#define D05726		
! 10
#define D01011_1931	
#define D01106_4555	
#define CDF0906_1014	
#define D05873		
#define CDF7307v3	
#define D06177		
#define CDF10439		
#define CDF9290_D05645	
#define D05757		
#define CDF0809_3930 	
! 20
#define CDF9465_D05754	
#define CDF10599	
#define D05871		
#define D01012_0874     
#define CDF0906_5613	
#define D01106_4885	
#define D05740		
#define D00912_5285	
#define CDF0911_3935	
#define D00901_1887	
! 30
#define D00712_0598	
#define CDF10099_D06063	
#define D05985  	
#define CDF9999         
#define D05739		
#define D00806_0611 	
#define D01001_4481	
#define D00903_4800	
#define D05845		
#define D06008		
! 40
#define CDF9998_D05983	
#define CDF10485	
#define CDF10010	
#define CDF1001_4468	
#define CDF_D0_1001_4162
#define CDF_D0_1005_3216
#define D06219
#define D06219singHWW
#define D01107_1268		
c deactivated #define D06083abslim  	
#define D06083
! 50
!temporary removed #define D00803_1514
#define CDF10241_D06096
#define D01008_3564
#define CDF10599singHWW
#define D05974
#define D06171
#define D06179
#define D06183                 
#define D06229                  
#define CDF10500                  
#define CDF10573
!60
#define CDF10574
#define CDF10596
#define CDF1106_4782
#define CDF_D0_1108_3331
#define CDF_D0_1103_3233
#define CDF_D0_1107_5518
#define CDF_D0_1107_5518bb
#define CDFD0_1107_4960	
#define ATLAS2011_134
!70
#define ATLAS1108_5064
#define ATLAS1109_3357
#define ATLAS2011_052
#define ATLAS1109_3615
#define ATLAS1202_1415
#define ATLAS1202_1414
!#define ATLAS1108_5895
#define ATLAS2011_133
#define ATLAS1107_5003
#define ATLAS2011_132
!80
#define ATLAS2011_103
#define ATLAS2011_112
#define ATLAS2011_135
!#define ATLAS1106_2748
!#define ATLAS1109_5945
#define ATLAS2011_163
#define ATLAS2011_148
#define ATLAS1112_2577
#define ATLAS2011_157_CMS11_023
#define CMS1202_1488
!90
#define CMS1202_1489
#define CMS1202_1997
#define CMS1202_3478
#define CMS1202_1416low
#define CMS1202_1416hi
#define CMS11_029SM
#define CMS1202_1487
#define CMS11_011
#define CMS11_031
#define CMS1104_1619
!100
#define CMS11_029
#define CMS1102_5429
#define ATLAS1202_1408

! single charged Higgs analyses
#define D00908_1811cs		
#define D00908_1811taunu	
#define CDF0907_1269low		
#define CDF0907_1269hi		
#define CMS11_008
#define ATLAS2011_138
#define ATLAS2011_151
#define ATLAS2011_094		
#define CDF7712		
#define CDF8353		


! double neutral Higgs analyses
#define D0_0905_3381_4mu
#define D0_0905_3381_2mu2tau
#define D06227
