!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

! /!\ :  All cross sections have been in units of femtobarn and are now given
!        in units of pikobarn. Hence, there is always an explicit division by 1000d0.

! functions are fitted to data 
! downloaded from http://maltoni.home.cern.ch/maltoni/TeV4LHC/bbh-tev_ed.dat
! on Thursday 10th April 2008
! data has range 100 to 300 GeV
 
!****************************************************** 
       function SMCS_tev_HW(x)
!******************************************************
       implicit none
       double precision  SMCS_tev_HW,x 
       double precision  a0,a0p5,a1,a2
       
       a0 = 5.7514105496046D0
       a0p5 = -0.375021739545092D0
       a1 = 0.0049451487167627D0
       a2 = -3.77008582179264D-06
       
       if(x.lt.65.0D0)then
        write(*,*) 'function SMCS_tev_HW(Mh) called out of range (m_H < 65 GeV). Value set to -1.' 
	SMCS_tev_HW=-1000d0
       elseif(x.le.335.0D0)then
        SMCS_tev_HW=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*) 'HB WARNING: SMCS_tev_HW(Mh) called out of range (m_H > 335 GeV). Value set to -1.' 
	SMCS_tev_HW=-1000d0
       endif 

       SMCS_tev_HW=SMCS_tev_HW/1000d0
       
       end


!****************************************************** 
       function SMCS_tev_HZ(x)
!****************************************************** 
       implicit none
       double precision  SMCS_tev_HZ,x 
       double precision  a0,a0p5,a1,a2
 
       a0 = 5.29935340004443D0
       a0p5 = -0.351677660532052D0
       a1 = 0.0047848452802514D0
       a2 = -3.82425969474559D-06 
       
       if(x.lt.65.0D0)then
        write(*,*) 'HB WARNING: SMCS_tev_HZ(Mh) called out of range (m_H < 65 GeV). Value set to -1.' 
	SMCS_tev_HZ=-1000d0
       elseif(x.le.335.0D0)then
        SMCS_tev_HZ=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*) 'HB WARNING: SMCS_tev_HZ(Mh) called out of range (m_H > 335 GeV). Value set to -1.' 
        SMCS_tev_HZ=-1000d0
       endif 
 
       SMCS_tev_HZ=SMCS_tev_HZ/1000d0
        
       end 


!****************************************************** 
       function SMCS_tev_gg_H(x)
!******************************************************
       implicit none
       double precision  SMCS_tev_gg_H,x 
       double precision  a0,a0p5,a1,a2
 
       a0 = 2.82844783978179
       a0p5 = -0.238895314316816
       a1 = -0.00244189137753305
       a2 = 7.90070235250398e-06 
	
       if(x.lt.65.0D0)then
        write(*,*) 'HB WARNING: SMCS_tev_gg_H(Mh) called out of range (m_H < 65 GeV). Value set to -1.' 
	SMCS_tev_gg_H=-1000d0
       elseif(x.le.335.0D0)then
        SMCS_tev_gg_H=10.0D0**3.0D0*10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*) 'HB WARNING: SMCS_tev_gg_H(Mh) called out of range (m_H > 335 GeV). Value set to -1.' 
        SMCS_tev_gg_H=-1000d0
       endif 
 
       SMCS_tev_gg_H=SMCS_tev_gg_H/1000d0 
       
       end 


!****************************************************** 
       function SMCS_tev_bb_H(x)
!******************************************************
       implicit none
       double precision  SMCS_tev_bb_H,x 
       double precision  a0,a0p5,a1,a2
 
       a0 = 5.41583328209568D0
       a0p5 = -0.453323023285831D0
       a1 = 0.00514220061294974D0
       a2 = -3.31488355831377D-06
	
       if(x.lt.65.0D0)then
        write(*,*) 'HB WARNING: SMCS_tev_bb_H(Mh) called out of range (m_H < 65 GeV). Value set to -1.' 
	SMCS_tev_bb_H=-1000d0
       elseif(x.le.335.0D0)then
        SMCS_tev_bb_H=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*) 'HB WARNING: SMCS_tev_bb_H(Mh) called out of range (m_H > 335 GeV). Value set to -1.' 
        SMCS_tev_bb_H=-1000d0
       endif  

       SMCS_tev_bb_H=SMCS_tev_bb_H/1000d0
 
       end 



!****************************************************** 
       function SMCS_tev_vbf_H(x)
!******************************************************
       implicit none
       double precision  SMCS_tev_vbf_H,x 
       double precision  a0,a0p5,a1,a2
 
       a0 = 3.03330688577339D0
       a0p5 = -0.061167148821396D0
       a1 = -0.00424395931917914D0
       a2 = 7.67964289500027D-08
	
       if(x.lt.65.0D0)then
        write(*,*)'HB WARNING: SMCS_tev_vbf_H(Mh) called out of range (m_H < 65 GeV). Value set to -1.' 
	SMCS_tev_vbf_H=-1000d0
       elseif(x.le.335.0D0)then
        SMCS_tev_vbf_H=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*)'HB WARNING: SMCS_tev_vbf_H(Mh) called out of range (m_H > 335 GeV). Value set to -1.' 
        SMCS_tev_vbf_H=-1000d0
       endif  

       SMCS_tev_vbf_H=SMCS_tev_vbf_H/1000d0
 
       end 


!****************************************************** 
	function SMCS_tev_ttH(x)
!******************************************************
       	implicit none
       	double precision SMCS_tev_ttH,x 
	double precision a0,a0p5,a1,a2
! fit from Karina	 
	a0 = 1.23241191811843D0
	a0p5 = 0.188533306634442D0
	a1 = -0.0240486573108739D0
	a2 = 1.90098085776576D-05
	          
 
       if(x.lt.60.0D0)then
        write(*,*)'HB WARNING: SMCS_tev_ttH(Mh) called out of range (m_H < 60 GeV). Value set to -1.' 
	SMCS_tev_ttH=-1000d0
       elseif(x.le.335.0D0)then
        SMCS_tev_ttH=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*)'HB WARNING: SMCS_tev_ttH(Mh) called out of range (m_H > 335 GeV). Value set to -1.' 
        SMCS_tev_ttH=-1000d0
       endif  

       SMCS_tev_ttH=SMCS_tev_ttH/1000d0

 
       end 


!******************************************************
! FUNCTIONS FOR LHC AT 7 TEV
! nb: These functions are in units of pb !! CHECK THAT!!
!******************************************************

!******************************************************
      function SMCS_lhc7_gg_H(x)
!******************************************************
      implicit none
      double precision SMCS_lhc7_gg_H
      double precision x,func,loval,hival
      double precision a0,a0p5,a1,a2,b1,b2,b3,b4,b5,c1,c2,c3,c4,c5
 
      a0 = 2.78261222779432D0
      a0p5 = -0.392196551818852D0
      a1 = 0.0117978237757204D0
      a2 = -4.17151874265905D-06
      b1 = -6496.34228398077D0
      b2 = 174.334182737679D0
      b3 = 96.344419701078D0
      b4 = 351.731389836777D0
      b5 = 41.8042207045728D0
      c1 = 1378.60118731267D0
      c2 = 331.890749316436D0
      c3 = 427.044291881834D0
      c4 = 395.248606977478D0
      c5 = -31.7761947614136D0
		
       loval=79.0d0
       hival=1001.0d0

       if(x .lt. loval )then
        write(*,*)'HB WARNING: SMCS_lhc7_gg_H(Mh) called out of range (m_H < ',loval,' GeV). Value set to -1.' 
	func=-1d0
       elseif(x .le. hival )then
        func=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0 
     & 	  +b1*exp(-(x-b2)**2.0D0/(b3**2.0D0))/((x-b4)**2.0D0+b5**2.0D0) 
     &    +c1*exp(-(x-c2)**2.0D0/(c3**2.0D0))/((x-c4)+c5**2.0D0))
       else
        write(*,*)'HB WARNING: SMCS_lhc7_gg_H(Mh) called out of range (m_H > ',hival,' GeV). Value set to -1.' 
        func=-1d0
       endif  

      SMCS_lhc7_gg_H=func
 
      end
      
      
!******************************************************
      function SMCS_lhc7_bb_H(x)
!******************************************************
!* fit to single Higgs production via b b-bar annihilation 
!* for a 7 TeV pp collider (NNLO QCD).
!* Numbers generated with bbh@nnlo v. 1.3 (PDF: MSTW 2008 NNLO) 
!* with input parameters according to arXiv:1101.0593 [hep-ph].
!******************************************************
!* SMCS_lhc7_cs_bbH : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: valid in range [70:1020], deviations from data table below 0.03%
!* 28/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************
      implicit none
      double precision SMCS_lhc7_bb_H
      double precision x,func,loval,hival
      double precision i1,j1,k1,a1,b1,c1,d1,e1,f1,g1,h1

      i1 = 118393.552970347d0
      j1 = -8500.14886364116d0
      k1 = 263.791637006274d0
      a1 = -0.686328023297912d0
      b1 = -0.0263560546043822d0
      c1 = 4.25891594291875d-05
      d1 = -6.72674484878268d-08
      e1 = 7.68476123865973d-11
      f1 = -5.76921139630906d-14
      g1 = 2.52072437882796d-17
      h1 = -4.83311237805624d-21

       loval=79.0d0
       hival=1001.0d0

       if(x .lt. loval )then
        write(*,*)'HB WARNING: SMCS_lhc7_bb_H(Mh) called out of range (m_H < ',loval,' GeV). Value set to -1.' 
	func=-1d0
       elseif(x .le. hival )then
        func=exp( i1/x**3+j1/x**2+k1/x+a1+b1*x+c1*x**2 
     &     +d1*x**3+e1*x**4+f1*x**5+g1*x**6+h1*x**7  )
       else
        write(*,*)'HB WARNING: SMCS_lhc7_bb_H(Mh) called out of range (m_H > ',hival,' GeV). Value set to -1.' 
        func=-1d0
       endif  

      SMCS_lhc7_bb_H=func
 
      end
      
      
!****************************************************** 
      function SMCS_lhc7_HW(x)
!******************************************************
      implicit none
      double precision SMCS_lhc7_HW
      double precision x,func,loval,hival
      double precision a0,a0p5,a1,a2
      
      a0 = 3.47925709357706D0
      a0p5 = -0.405519201979233D0
      a1 = 0.006675415284311D0
      a2 = -1.66890554788541D-06
      
       loval=79.0d0
       hival=305.0d0

       if(x .lt. loval )then
        write(*,*)'HB WARNING: SMCS_lhc7_HW(Mh) called out of range (m_H < ',loval,' GeV). Value set to -1.' 
	func=-1d0
       elseif(x .le. hival )then
        func=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*)'HB WARNING: SMCS_lhc7_HW(Mh) called out of range (m_H > ',hival,' GeV). Value set to -1.' 
        func=-1d0
       endif  

      SMCS_lhc7_HW=func

      end
      
      
!****************************************************** 
      function SMCS_lhc7_HZ(x)
!****************************************************** 
      implicit none
      double precision SMCS_lhc7_HZ
      double precision x,func,loval,hival
      double precision a0,a0p5,a1,a2
 
      a0 = 2.98356567605733D0
      a0p5 = -0.381566481668429D0
      a1 = 0.00666517818082496D0
      a2 = -3.40355207948873D-06

       loval=79.0d0
       hival=305.0d0

       if(x .lt. loval )then
        write(*,*)'HB WARNING: SMCS_lhc7_HZ(Mh) called out of range (m_H < ',loval,' GeV). Value set to -1.' 
	func=-1d0
       elseif(x .le. hival )then
        func=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*)'HB WARNING: SMCS_lhc7_HZ(Mh) called out of range (m_H > ',hival,' GeV). Value set to -1.' 
        func=-1d0
       endif  

      SMCS_lhc7_HZ=func

      end
      
      
!****************************************************** 
      function SMCS_lhc7_vbf_H(x)
!******************************************************
      implicit none
      double precision SMCS_lhc7_vbf_H
      double precision x,func,loval,hival
      double precision a0,a0p5,a1,a2
 
      a0 = 1.05101126849124D0
      a0p5 = -0.0781389982071239D0
      a1 = -0.000788771622392916D0
      a2 = 2.55014215205304D-07
	
       loval=79.0d0
       hival=1001.0d0

       if(x .lt. loval )then
        write(*,*)'HB WARNING: SMCS_lhc7_vbf_H(Mh) called out of range (m_H < ',loval,' GeV). Value set to -1.' 
	func=-1d0
       elseif(x .le. hival )then
        func=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*)'HB WARNING: SMCS_lhc7_vbf_H(Mh) called out of range (m_H > ',hival,' GeV). Value set to -1.' 
        func=-1d0
       endif  

      SMCS_lhc7_vbf_H= func

      end
      
      
!****************************************************** 
      function SMCS_lhc7_ttH(x)
!******************************************************
      implicit none
      double precision SMCS_lhc7_ttH
      double precision x,func,loval,hival
      double precision a0,a0p5,a1,a2
 	
      a0 = 1.30235892285854D0
      a0p5 = -0.160563741042278D0
      a1 = -0.00582434890060432D0
      a2 = 1.00116051386356D-05

       loval=79.0d0
       hival=305.0d0

       if(x .lt. loval )then
        write(*,*)'HB WARNING: SMCS_lhc7_ttH(Mh) called out of range (m_H < ',loval,' GeV). Value set to -1.' 
	func=-1d0
       elseif(x .le. hival )then
        func=10.0D0**(a0+a0p5*x**0.5D0+a1*x+a2*x**2.0D0)
       else
        write(*,*)'HB WARNING: SMCS_lhc7_ttH(Mh) called out of range (m_H > ',hival,' GeV). Value set to -1.' 
        func=-1d0
       endif  

      SMCS_lhc7_ttH=  func

      end
